<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Ads;

class AdsController extends Controller
{
    //

    public function createAds(Request $request)
    {

        try {
            $request->validate([
                'image' => 'required|image',
                'link' => 'required',
            ]);
            

            $path = '';
            if ($request->image && $request->image->isValid()) {
                $path = $this->fileUploadApi('ads_images',$request->file('image'));
            }

            $ads = Ads::insert([
                'link' => $request->link,
                'image' => $path,
                'created_at'=>date('Y-m-d H:i:s'),
                'updated_at'=>date('Y-m-d H:i:s')
            ]);

            return response()->json([
                'success' => true,
                'message' => 'Ads Inserted Successfully',
                'data' => $ads,
            ]);
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function listAds()
    {
        try {
            if (auth()->user()) {

                $ads = Ads::get();

                return response()->json([
                    'success' => true,
                    'data' => $ads,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'User is not Authenticated.']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }


    public function deleteAds($id)
    {
        try {
            $ads = Ads::find($id);
            if ($ads) {
                Ads::where('id', $id)->delete();
                return response()->json(['success' => true, 'message' => 'Ads Deleted.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Ads `Not Found!']);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    function fileUploadApi($path,$file)
    {
        $filename = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
        $imageName = $filename.rand(1000,99999).time().'.'.$file->getClientOriginalExtension();
        $file->move(base_path().'/public/'.$path,$imageName);
        return url('/').'/'.$path.'/'.$imageName;
    }
}
