<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\Banner;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class BannerController extends Controller
{
    //
    public function createBanner(Request $request)
    {

        try {
            $request->validate([
                'image' => 'required|image',
                'name' => 'required',
                'course_id' => 'required',
                'link' => 'required',
            ]);


            $path = '';
            if ($request->image && $request->image->isValid()) {
                $path = $this->fileUploadApi('Banner_images',$request->file('image'));
            }

            $banner = DB::table('banner')->insert([
                'image' => $path,
                'name' => $request->name,
                'course_id' => $request->course_id,
                'link' => $request->link,
            ]);

            return response()->json([
                'success' => true,
                'message' => 'Banner Inserted Successfully',
                'data' => $banner,
            ]);
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function listBanner()
    {
        try {
            if (auth()->user()) {

                $banner = DB::table('banner')->join('courses', 'courses.id', '=', 'banner.course_id')
                ->select('banner.*','courses.name as course_name')
                ->get();

                return response()->json([
                    'success' => true,
                    'data' => $banner,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'User is not Authenticated.']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }


    public function deleteBanner($id)
    {
        try {
            $banner = DB::table('banner')->find($id);
            if ($banner) {
                DB::table('banner')->where('id', $id)->delete();
                return response()->json(['success' => true, 'message' => 'Banner Deleted.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Banner `Not Found!']);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    function fileUploadApi($path,$file)
    {
        $filename = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
        $imageName = $filename.rand(1000,99999).time().'.'.$file->getClientOriginalExtension();
        $file->move(base_path().'/public/'.$path,$imageName);
        return url('/').'/'.$path.'/'.$imageName;
    }
}
