<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\PollCategory;
use App\Models\Poll;
use App\Models\PollResult;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;

class PollController extends Controller
{
    //

    // poll api
    public function createPoll(Request $request)
    {
        try {
            $request->validate([
                'title' => 'required|string|min:2',
                'description' => 'required',
                'news_category_id' => 'required|numeric',
                'image' => 'required|image',
                'question' => 'required',
            ]);

            $path = '';
            if ($request->image && $request->image->isValid()) {
                $path = $this->fileUploadApi('poll_images', $request->file('image'));
                // $file_name = time() . '.' . $request->image->extension();
                // $request->file('image')->storeAs('public/poll_images',$file_name);
                //     $path = env('APP_URL') ."/storage/poll_images/$file_name";
                // $request->image->move(public_path('poll_images'), $file_name);
                // $path = env('APP_URL')."/poll_images/$file_name";
                // $path = "public/poll_images/$file_name";
            }

            $poll = Poll::create([
                'title' => $request->title,
                'description' => $request->description,
                'news_category_id' => $request->news_category_id,
                'image' => $path,
                'link' => $request->link,
                'question' => $request->question,
            ]);

            return response()->json([
                'success' => true,
                'message' => 'poll Feed Inserted Successfully',
                'data' => $poll,
            ]);
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function listPoll()
    {
        try {
            if (auth()->user()) {

                $data['poll'] = Poll::join('news_categories', 'news_categories.id', '=', 'polls.news_category_id')
                    ->leftJoin('poll_results', 'polls.id', '=', 'poll_results.poll_id')
                    ->select('polls.*', 'news_categories.name as categories_name', DB::raw('SUM(if(poll_results.answer = "0", 1, 0)) AS negetive_count'), DB::raw('SUM(if(poll_results.answer = "1", 1, 0)) AS possitive_count'), DB::raw('SUM(if(poll_results.user_id  = "' . auth()->id() . '", 1, 0)) AS status'))
                    ->groupBy('polls.id')
                    ->get();
                // $data['poll_pagination'] = Poll::join('news_categories', 'news_categories.id', '=', 'polls.news_category_id')
                //     ->select('polls.*', 'news_categories.name as categories_name')
                //     ->paginate(5);

                //         $data['total_count'] = PollResult::where('poll_id', $id)->count();
                // $data['possitive_count'] = PollResult::where('poll_id', $id)->where('answer', 1)->count();
                // $data['negetive_count'] = PollResult::where('poll_id', $id)->where('answer', 0)->count();
                // $data['possitive_count_percentage'] = 0;
                // $data['negetive_count_percentage'] = 0;
                // if ($data['total_count'] >= 1) {
                //     $data['possitive_count_percentage'] = ($data['possitive_count'] / $data['total_count']) * 100;
                //     $data['negetive_count_percentage'] = ($data['negetive_count'] / $data['total_count']) * 100;
                // }
                return response()->json([
                    'success' => true,
                    'data' => $data,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'User is not Authenticated.']);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function editPoll($id)
    {
        $poll = Poll::find($id);
        if ($poll) {
            return response()->json(['success' => true, 'data' => $poll]);
        }
        return response()->json(['success' => false, 'message' => 'Poll Feed Not Found!']);
    }

    public function updatePoll(Request $request)
    {
        try {
            $request->validate([
                'id' => 'required|numeric',
            ]);

            $poll = Poll::find($request->id);
            $input = $request->all();
            if ($poll) {
                if ($request->image && $request->image->isValid()) {
                    $path = $this->fileUploadApi('poll_images', $request->file('image'));
                    // $file_name = time() . '.' . $request->image->extension();
                    // $request->file('image')->storeAs('public/poll_images',$file_name);
                    // $path = env('APP_URL') ."/storage/poll_images/$file_name";
                    // $request->image->move(public_path('poll_images'), $file_name);
                    // $path = env('APP_URL')."/poll_images/$file_name";
                    // $path = "public/poll_images/$file_name";
                    $input['image'] = $path;
                } else {
                    unset($input['image']);
                }
                $poll->update($input);
                return response()->json(['success' => true, 'data' => $poll, 'message' => 'Poll Updated.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Poll Feed Not Found!']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function deletePoll($id)
    {
        try {
            $poll = Poll::find($id);
            if ($poll) {
                PollResult::where("poll_id",$id)->delete();
                Poll::where('id', $id)->delete();
                return response()->json(['success' => true, 'message' => 'Poll Deleted.']);
            } else {
                return response()->json(['success' => false, 'message' => 'Poll Not Found!']);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function listPollCategoryWise(Request $request)
    {
        try {
            if (auth()->user()) {
                $request->validate([
                    'news_category_id' => 'required|numeric',
                ]);


                // $poll = Poll::where('news_category_id', $request->news_category_id)->paginate(5);
                $poll = Poll::join('news_categories', 'news_categories.id', '=', 'polls.news_category_id')
                    ->leftJoin('poll_results', 'polls.id', '=', 'poll_results.poll_id')
                    ->select('polls.*', 'news_categories.name as categories_name', DB::raw('SUM(if(poll_results.answer = "0", 1, 0)) AS negetive_count'), DB::raw('SUM(if(poll_results.answer = "1", 1, 0)) AS possitive_count'), DB::raw('SUM(if(poll_results.user_id  = "' . auth()->id() . '", 1, 0)) AS status'))
                    ->where('news_category_id', $request->news_category_id)
                    ->groupBy('polls.id')
                    ->paginate(5);

                if (count($poll) > 0) {

                    return response()->json([
                        'success' => true,
                        'data' => $poll,
                    ]);
                } else {
                    return response()->json(['success' => false, 'message' => 'Poll Not Found!']);
                }
            } else {
                return response()->json(['success' => false, 'message' => 'User is not Authenticated.']);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

 public function PollResult(Request $request)
    {
        try {
            if (auth()->user()) {
                $request->validate([
                    'poll_id' => 'required|numeric',
                    'answer' => 'required|boolean',
                ]);

                $poll = Poll::find($request->poll_id);
                if ($poll) {
                    $poll_result = PollResult::where('user_id', auth()->id())
                        ->where('poll_id', $poll->id)->get();
                    if (count($poll_result) > 0) {
                        PollResult::where('user_id', auth()->id())
                            ->where('poll_id', $poll->id)
                            ->update([
                                'answer' => $request->answer
                            ]);
                            $u_poll = Poll::join('news_categories', 'news_categories.id', '=', 'polls.news_category_id')
                            ->leftJoin('poll_results', 'polls.id', '=', 'poll_results.poll_id')
                            ->select('polls.*', 'news_categories.name as categories_name', DB::raw('SUM(if(poll_results.answer = "0", 1, 0)) AS negetive_count'), DB::raw('SUM(if(poll_results.answer = "1", 1, 0)) AS possitive_count'), DB::raw('SUM(if(poll_results.user_id  = "' . auth()->id() . '", 1, 0)) AS status'))
                            ->where('polls.id', $poll->id)
                            ->groupBy('polls.id')
                            ->first();
                        return response()->json(['success' => true, 'data' => $u_poll, 'message' => 'Your Answer Updated.']);
                    } else {
                        $poll_result = PollResult::create([
                            'user_id' => auth()->id(),
                            'poll_id' => $poll->id,
                            'answer' => $request->answer,
                        ]);

                        $poll = Poll::join('news_categories', 'news_categories.id', '=', 'polls.news_category_id')
                            ->leftJoin('poll_results', 'polls.id', '=', 'poll_results.poll_id')
                            ->select('polls.*', 'news_categories.name as categories_name', DB::raw('SUM(if(poll_results.answer = "0", 1, 0)) AS negetive_count'), DB::raw('SUM(if(poll_results.answer = "1", 1, 0)) AS possitive_count'), DB::raw('SUM(if(poll_results.user_id  = "' . auth()->id() . '", 1, 0)) AS status'))
                            ->where('polls.id', $poll->id)
                            ->groupBy('polls.id')
                            ->first();
                        return response()->json(['success' => true, 'data' => $poll, 'message' => 'Added Poll to Answer.']);
                    }
                } else {
                    return response()->json(['success' => false, 'message' => 'Poll Feed Not Found!']);
                }
            } else {
                return response()->json(['success' => false, 'message' => 'User is not Authenticated.']);
            }
        } catch (\Exception $e) {
            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }


    public function viewPoll($id)
    {
        $poll = Poll::where('id', $id)->first();
        if ($poll) {
            $data['poll'] = $poll;
            $data['total_count'] = PollResult::where('poll_id', $id)->count();
            $data['possitive_count'] = PollResult::where('poll_id', $id)->where('answer', 1)->count();
            $data['negetive_count'] = PollResult::where('poll_id', $id)->where('answer', 0)->count();
            $data['possitive_count_percentage'] = 0;
            $data['negetive_count_percentage'] = 0;
            if ($data['total_count'] >= 1) {
                $data['possitive_count_percentage'] = ($data['possitive_count'] / $data['total_count']) * 100;
                $data['negetive_count_percentage'] = ($data['negetive_count'] / $data['total_count']) * 100;
            }
            return response()->json(['success' => true, 'data' => $data]);
        } else {
            return response()->json(['success' => true, 'message' => 'Poll not found.']);
        }
    }

    function fileUploadApi($path, $file)
    {
        $filename = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
        $imageName = $filename . rand(1000, 99999) . time() . '.' . $file->getClientOriginalExtension();
        $file->move(base_path() . '/public/' . $path, $imageName);
        return url('/') . '/' . $path . '/' . $imageName;
    }
}
