<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\WealthCategoryColor;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class WealthColorController extends Controller
{

    /* APP API */
    public function add(Request $request)
    {
        try {
            $request->validate([
                'color' => 'required',
            ]);

            $category = new WealthCategoryColor();
            $category->color = $request->color;

            $category->save();


            return response()->json([
                'success' => true,
                'data' => $category,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }


    public function single(Request $request)
    {
        try {
            $request->validate([
                'id' => 'required'
            ]);

            $color = WealthCategoryColor::where('id', $request->id)->first();

            if (isset($color->id) && $color->id > 0) {

                return response()->json([
                    'success' => true,
                    'data' => $color,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'No color found']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function update(Request $request)
    {
        try {
            $request->validate([
                'color' => 'required',
                'id' => 'required'
            ]);

            $color = WealthCategoryColor::findOrFail($request->id);
            $color->color = $request->color;

            $color->save();


            return response()->json([
                'success' => true,
                'data' => $color,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function list(Request $request)
    {
        try {
            $color = WealthCategoryColor::all();

            if (isset($color) && count($color) > 0) {
                return response()->json([
                    'success' => true,
                    'data' => $color,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'No data found']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function delete($id)
    {
        try {
            $category = WealthCategoryColor::findOrFail($id);
            $category->delete();
            return response()->json([
                'success' => true,
                'message' => 'color data successfully deleted',
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    function fileUploadApi($path, $file)
    {
        $filename = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
        $imageName = $filename . rand(1000, 99999) . time() . '.' . $file->getClientOriginalExtension();
        $file->move(base_path() . '/public/' . $path, $imageName);
        return url('/') . '/' . $path . '/' . $imageName;
    }
}
