<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\WealthCategoryIcon;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class WealthIconController extends Controller
{

    /* APP API */
    public function add(Request $request)
    {
        try {
            $request->validate([
                'icon' => 'required',
            ]);

            $path = '';
            if ($request->icon && $request->icon->isValid()) {
                $path = $this->fileUploadApi('category_icon', $request->file('icon'));
            }

            $category = new WealthCategoryIcon();
            $category->icon = $path;

            $category->save();


            return response()->json([
                'success' => true,
                'data' => $category,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }


    public function single(Request $request)
    {
        try {
            $request->validate([
                'id' => 'required'
            ]);

            $icon = WealthCategoryIcon::where('id', $request->id)->first();

            if (isset($icon->id) && $icon->id > 0) {

                return response()->json([
                    'success' => true,
                    'data' => $icon,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'No icon found']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function update(Request $request)
    {
        try {
            $request->validate([
                'icon' => 'required',
                'id' => 'required'
            ]);

            $icon = WealthCategoryIcon::findOrFail($request->id);
            $path = '';
            if ($request->icon && $request->icon->isValid()) {
                $path = $this->fileUploadApi('category_icon', $request->file('icon'));
                $icon->icon = $path;
            }

            $icon->save();


            return response()->json([
                'success' => true,
                'data' => $icon,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function list(Request $request)
    {
        try {
            $icon = WealthCategoryIcon::all();

            if (isset($icon) && count($icon) > 0) {
                return response()->json([
                    'success' => true,
                    'data' => $icon,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'No data found']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function delete($id)
    {
        try {
            $category = WealthCategoryIcon::findOrFail($id);
            $category->delete();
            return response()->json([
                'success' => true,
                'message' => 'icon data successfully deleted',
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    function fileUploadApi($path, $file)
    {
        $filename = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
        $imageName = $filename . rand(1000, 99999) . time() . '.' . $file->getClientOriginalExtension();
        $file->move(base_path() . '/public/' . $path, $imageName);
        return url('/') . '/' . $path . '/' . $imageName;
    }
}
