<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Models\WealthSplitEvent;
use App\Models\WealthSplitEventMember;
use App\Models\WealthSplitMember;
use App\Models\WealthSplitTransaction;
use App\Models\WealthSplitTransactionMember;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class WealthSplitEventController extends Controller
{

    /* APP API */
    public function add(Request $request)
    {
        try {
            $request->validate([
                'user_id' => 'required',
                'name' => 'required',
                'event_type' => 'required',
                'member' => 'required'
            ]);

            $event = new WealthSplitEvent();
            $event->user_id = $request->user_id;
            $event->name = $request->name;
            $event->event_type = strtoupper($request->event_type);
            $event->save();

            $id = $event->id;

            $memberData = $request->member;
            if (isset($memberData) && !empty($memberData)) {
                foreach ($memberData as $key => $val) {
                    $member = new WealthSplitMember();
                    $member->event_id = $id;
                    $member->name = $val;
                    $member->user_id = ($key == 0) ? $request->user_id : null;
                    $member->save();
                }
            }


            return response()->json([
                'success' => true,
                'data' => $event,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function update(Request $request)
    {
        try {
            $request->validate([
                'user_id' => 'required',
                'name' => 'required',
                'event_type' => 'required',
                'id' => 'required',
                'member' => 'required'
            ]);

            $event = WealthSplitEvent::findOrFail($request->id);

            $event->user_id = $request->user_id;
            $event->name = $request->name;
            $event->event_type = strtoupper($request->event_type);

            $event->save();

            $memberQuery = WealthSplitMember::where('event_id', $request->id)->get();
            $eventExistingMember = array();
            if (isset($memberQuery) && count($memberQuery) > 0) {
                foreach ($memberQuery as $key => $val) {
                    array_push($eventExistingMember, $val->name);
                }
            }

            $memberData = $request->member;

            if (isset($eventExistingMember) && !empty($eventExistingMember)) {
                foreach ($eventExistingMember as $key => $val) {
                    if (in_array($val, $memberData)) {
                        //do nothing
                    } else {
                        WealthSplitMember::where('name', $val)->where('event_id', $request->id)->delete();
                    }
                }
            }


            if (isset($memberData) && !empty($memberData)) {
                foreach ($memberData as $key => $val) {
                    if (in_array($val, $eventExistingMember)) {
                        // do nothing
                    } else {
                        $member = new WealthSplitMember();
                        $member->event_id = $request->id;
                        $member->name = $val;
                        $member->save();
                    }
                }
            }


            return response()->json([
                'success' => true,
                'data' => $event,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function single(Request $request)
    {
        try {
            $request->validate([
                'event_id' => 'required'
            ]);

            $event = WealthSplitEvent::with('member')->where('id', $request->event_id)->first();

            if (isset($event->id) && $event->id > 0) {

                return response()->json([
                    'success' => true,
                    'data' => $event,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'No event found']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function list(Request $request)
    {
        try {
            $request->validate([
                'user_id' => 'required',
                'event_type' => 'required',
            ]);

            $event = WealthSplitEvent::select('wealth_split_event.*')->with('member')
                ->leftJoin('wealth_split_event_member as wsem', 'wsem.event_id', '=', 'wealth_split_event.id')
                ->whereRaw("(wealth_split_event.user_id = '" . $request->user_id . "' OR wsem.user_id = '" . $request->user_id . "') AND wealth_split_event.event_type = '" . $request->event_type . "'")->groupBy('wealth_split_event.id')
                /* ->where('wealth_split_event.event_type', $request->event_type)
                ->Where('wealth_split_event.user_id', $request->user_id)
                ->OrWhere('wsem.user_id', $request->user_id) */
                ->get();

            if (isset($event) && count($event) > 0) {
                return response()->json([
                    'success' => true,
                    'data' => $event,
                ]);
            } else {
                return response()->json(['success' => false, 'message' => 'No data found']);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function delete(Request $request)
    {
        try {
            $request->validate([
                'event_id' => 'required'
            ]);



            $tran = WealthSplitTransaction::where('event_id', $request->event_id)->get();
            if (isset($tran) && count($tran) > 0) {
                foreach ($tran as $key => $val) {
                    WealthSplitTransactionMember::where('transaction_id', $val->id)->delete();
                }
            }
            WealthSplitTransaction::where('event_id', $request->event_id)->delete();
            WealthSplitMember::where('event_id', $request->event_id)->delete();
            WealthSplitEventMember::where('event_id', $request->event_id)->delete();


            $event = WealthSplitEvent::findOrFail($request->event_id);
            $event->delete();





            return response()->json([
                'success' => true,
                'message' => 'event data successfully deleted',
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function shareevent($event_id, $user_id)
    {
        try {
            if (isset($event_id, $user_id) && $user_id > 0 && $event_id > 0) {

                $chkEventExit = WealthSplitEvent::where('id', $event_id)->first();

                if (isset($chkEventExit->id) && $chkEventExit->id > 0) {

                    $chkUserExit = User::where('id', $user_id)->first();
                    if (isset($chkUserExit->id) && $chkUserExit->id > 0) {

                        $chkShare = WealthSplitEventMember::where('event_id', $event_id)->where('user_id', $user_id)->first();

                        if (isset($chkShare->id) && $chkShare->id > 0) {
                            return response()->json([
                                'success' => false,
                                'message' => 'Event data already shared.',
                            ]);
                        } else {
                            if (isset($chkEventExit->user_id) && $chkEventExit->user_id == $user_id) {
                                return response()->json([
                                    'success' => false,
                                    'message' => 'Sorry!! Event data already shared.',
                                ]);
                            } else {
                                $newShare = new WealthSplitEventMember();
                                $newShare->event_id = $event_id;
                                $newShare->user_id = $user_id;

                                $newShare->save();

                                /* $chkWSM = WealthSplitMember::where('event_id', $event_id)->where('name', $chkUserExit->name)->first();
                                if (isset($chkWSM->id) && $chkWSM->id > 0) {
                                    //do nothing
                                } else {

                                    $member = new WealthSplitMember();
                                    $member->event_id = $event_id;
                                    $member->name = $chkUserExit->name;
                                    $member->save();
                                } */

                                return response()->json([
                                    'success' => true,
                                    'type' => $chkEventExit->event_type,
                                    'message' => 'event data successfully shared',
                                ]);
                            }
                        }
                    } else {
                        return response()->json([
                            'success' => false,
                            'message' => 'Sorry!! user does not exists.',
                        ]);
                    }
                } else {
                    return response()->json([
                        'success' => false,
                        'message' => 'Sorry!! event data does not exists.',
                    ]);
                }
            } else {
                return response()->json([
                    'success' => false,
                    'message' => 'event data and user data are required.',
                ]);
            }
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function shareEventMember(Request $request)
    {
        try {
            $request->validate([
                'user_id' => 'required',
                'event_id' => 'required',
                'member_id' => 'required',
            ]);

            if (isset($request->member_id) && $request->member_id > 0) {
                $member = WealthSplitMember::where('id', $request->member_id)->where('event_id', $request->event_id)->first();

                if (isset($member->id) && $member->id > 0) {
                    $memUpdate = WealthSplitMember::findOrFail($member->id);
                    $memUpdate->user_id = $request->user_id;
                    $memUpdate->save();

                    return response()->json([
                        'success' => true,
                        'message' => 'event data successfully shared.',
                    ]);
                }else{
                    return response()->json([
                        'success' => false,
                        'message' => 'Please select member.',
                    ]);
                }
            }else{
                return response()->json([
                    'success' => false,
                    'message' => 'Member id is required.',
                ]);
            }


        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    /* ADMIN API */

    public function addCategory(Request $request)
    {
        try {
            $request->validate([
                'title' => 'required',
                'icon' => 'required',
                'color' => 'required',
                'event_type' => 'required',
            ]);

            $path = '';
            if ($request->icon && $request->icon->isValid()) {
                $path = $this->fileUploadApi('event_icon', $request->file('icon'));
            }

            $event = new WealthSplitEvent();
            $event->title = $request->title;
            $event->color = $request->color;
            $event->icon = $path;
            $event->event_type = strtoupper($request->event_type);

            $event->save();


            return response()->json([
                'success' => true,
                'data' => $event,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    public function updateCategory(Request $request)
    {
        try {
            $request->validate([
                'title' => 'required',
                'color' => 'required',
                'event_type' => 'required',
                'id' => 'required'
            ]);

            $event = WealthSplitEvent::findOrFail($request->id);

            $path = '';
            if ($request->icon && $request->icon->isValid()) {
                $path = $this->fileUploadApi('event_icon', $request->file('icon'));
                $event->icon = $path;
            }

            $event->title = $request->title;
            $event->color = $request->color;
            $event->event_type = strtoupper($request->event_type);

            $event->save();


            return response()->json([
                'success' => true,
                'data' => $event,
            ]);
        } catch (\Exception $e) {

            return response()->json(['success' => false, 'message' => $e->getMessage()]);
        }
    }

    function fileUploadApi($path, $file)
    {
        $filename = pathinfo($file->getClientOriginalName(), PATHINFO_FILENAME);
        $imageName = $filename . rand(1000, 99999) . time() . '.' . $file->getClientOriginalExtension();
        $file->move(base_path() . '/public/' . $path, $imageName);
        return url('/') . '/' . $path . '/' . $imageName;
    }
}
