@extends('layouts.app')

@section('content')
    <div class="container-fluid">
        <!-- row -->
        <div class="row">
            <div class="col-lg-12">
                <div class="card">
                    <div class="card-header">
                        <h4 class="card-title">Vertical Forms with icon</h4>
                    </div>
                    <div id="response"></div>
                    <div class="card-body">
                        <div class="basic-form">
                            <form class="form-valide-with-icon" id="update-insight" enctype="multipart/form-data">

                                <input type="number" name="id" id="id" class="form-control" hidden>
                                <div class="mb-3">
                                    <label class="form-label">Select News Category</label>
                                    <select class="default-select  form-control wide" name="news_category_id"
                                        id="news_category_id">
                                        <option>Select News Category</option>
                                    </select>
                                </div>
                                <div class="mb-3 row">
                                    <label class="col-sm-3 col-form-label">Title</label>
                                    <div class="col-sm-12">
                                        <input type="text" name="title" id="title" class="form-control"
                                            placeholder="Title">
                                    </div>
                                </div>
                                <label class="col-sm-3 col-form-label">Image</label>
                                <div class="input-group">
                                    <div class="form-file">
                                        <input type="file" name="images[]" multiple="true" accept="image/*"
                                            class="form-file-input form-control">
                                        </div>
                                    </div>
                                    <div id="imageContent" class="d-flex gap-2"></div>
                                <div class="mb-3">
                                    <label class="col-sm-3 col-form-label">Description</label>
                                    <textarea class="form-control" name="description" rows="4" id="description"></textarea>
                                </div>
                                <button type="submit" class="btn me-2 btn-primary">Submit</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection


@section('script')
    <script>
        var token = sessionStorage.getItem('token');
        var url = "{{ env('APP_URL') }}";

        function editData() { 
            $.ajax({
                type: "GET",
                url: url + "/edit-insight/{{ request()->id }}",
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                headers: {
                    "Authorization": "Bearer " + token
                },
                success: function(msg) {
                    if (msg.success) {
                        $("#id").val(msg.data['id']);
                        $("#title").val(msg.data['title']);
                        $("#description").html(msg.data['description']);
                        $("#news_category_id").val(msg.data.news_category_id);
                        var images = msg.data.insight_image; 
                        for (var i = 0, j = images.length; i < j; i++) {
                            $("#imageContent").append("<div><img src='" + images[i].image + "' width='50'><br><a href='{{route('deleteInsightImage')}}?id="+images[i].id+"' class='text-danger'>Remove</a></div>");
                            console.log("asdf"+images);
                        }
                    } else {
                        $('#response').html("<div class='alert alert-danger'>" + msg.message + "</div>");
                    }
                }
            });
        }

        function displayCategoryData() {

            $.ajax({
                type: "GET",
                url: url + "/list-news-category",
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                headers: {
                    "Authorization": "Bearer " + token
                },
                success: function(msg) {
                    if (msg.success) {
                        var json = msg.data.category;
                        var row = '';
                        $.each(json, function(index, obj) {
                            row += "<option value='" + obj.id + "'>" + obj.name + "</option>";
                        });
                        $("#news_category_id").html(row);
                    } else if (msg.message == 'User is not Authenticated.') {
                        window.location = url + "/login-view";
                    } else {
                        $('#response').html("<div class='alert alert-danger'>" + msg.message + "</div>");
                    }
                }
            });

        }

        $('#update-insight').submit(function(event) {
            event.preventDefault();
            $('#response').html("");
            var formData = new FormData(this);

            $.ajax({
                url: url + "/update-insight",
                type: 'POST',
                data: formData,
                success: function(data) {
                    if (data.success) {
                        $('form#update-insight').trigger("reset");
                        window.location = url + "/list-insight-view";
                    } else {
                        $('#response').html("<div class='alert alert-danger'>" + data.message +
                            "</div>");
                    }
                },
                cache: false,
                contentType: false,
                processData: false
            });
        });

        $(document).ready(function() {
            CheckSession();
            displayCategoryData();
            editData();
        });
    </script>
@endsection
