@extends('layouts.app')

@section('content')
    <div class="container-fluid">
        <!-- row -->
        <div class="row">
            <div class="col-lg-12">
                <div class="card">
                    <div class="card-header">
                        <h4 class="card-title">Poll</h4>
                    </div>
                    <div class="card-body">
                        <div class="basic-form">
                            <form class="form-valide-with-icon" id="poll" enctype="multipart/form-data">
                                <div class="mb-3">
                                    <label class="form-label">News Category Id</label>
                                    <select class="form-control wide" name="news_category_id"
                                        id="news_category_id">
                                        <option>Poll Category Id</option>
                                    </select>
                                </div>
                                <div class="mb-3 row">
                                    <label class="col-sm-3 col-form-label">Title</label>
                                    <div class="col-sm-12">
                                        <input type="text" name="title" class="form-control" placeholder="Title">
                                    </div>
                                </div>

                                <div class="mb-3">
                                    <label class="col-sm-3 col-form-label">Description</label>
                                    <textarea class="form-control" rows="4" id="description" name="description"></textarea>
                                </div>
                                <div class="mb-3">
                                    <label class="col-sm-3 col-form-label">Image</label>
                                    <div class="input-group">
                                        <div class="form-file">
                                            <input type="file" name="image" accept="image/*" class="form-file-input form-control">
                                        </div>
                                    </div>
                                </div>
                                <div class="mb-3">
                                    <label class="col-sm-3 col-form-label">Link</label>
                                    <input class="form-control" id="link" name="link" placeholder="Link">
                                </div>
                                <div class="mb-3">
                                    <label class="col-sm-3 col-form-label">Question</label>
                                    <textarea class="form-control" rows="4" id="question" name="question"></textarea>
                                </div>
                                <button type="submit" class="btn me-2 btn-primary">Submit</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection

@section('script')
    <script>
        var token = sessionStorage.getItem('token');
        var url = "{{ env('APP_URL') }}";

        function displayCategoryData() {

            $.ajax({
                type: "GET",
                url: url + "/list-news-category",
                contentType: "application/json; charset=utf-8",
                dataType: "json",
                headers: {
                    "Authorization": "Bearer " + token
                },
                success: function(msg) {
                    console.log(msg);
                    if (msg.success) {
                        var json = msg.data.category;
                        var row = '';
                        $.each(json, function(index, obj) {
                            row += "<option value='" + obj.id + "'>" + obj.name + "</option>";
                        });
                        $("#news_category_id").html(row);
                    } else if (msg.message == 'User is not Authenticated.') {
                        window.location = url + "/login-view";
                    } else {
                        $('#response').html("<div class='alert alert-danger'>" + msg.message +
                            "</div>");
                    }
                }
            });

        }

        $('#poll').submit(function(event) {
            event.preventDefault();

            // var formData = $(this).serialize();
            var formData = new FormData(this);

            $.ajax({
                url: url + "/create-poll",
                type: 'POST',
                data: formData,
                success: function(data) {
                    console.log(data);
                    if (data.success) {
                        $('form#poll').trigger("reset");
                        window.location = url + "/list-poll-view";
                    } else {
                        $('#response').html("<div class='alert alert-danger'>" + data
                            .message + "</div>");
                    }
                },
                cache: false,
                contentType: false,
                processData: false
            });
        });
        $(document).ready(function() {
            displayCategoryData();
        });
    </script>
@endsection
